Module api

Module api 

Structs

AcceptHubSpokeRequest
The request for HubService.AcceptHubSpoke.
AcceptSpokeUpdateRequest
The request for HubService.AcceptSpokeUpdate.
AllocationOptions
Range auto-allocation options, to be optionally used when CIDR block is not explicitly set.
AuditConfig
Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both allServices and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: { “audit_configs”: [ { “service”: “allServices”, “audit_log_configs”: [ { “log_type”: “DATA_READ”, “exempted_members”: [ “user:jose@example.com” ] }, { “log_type”: “DATA_WRITE” }, { “log_type”: “ADMIN_READ” } ] }, { “service”: “sampleservice.googleapis.com”, “audit_log_configs”: [ { “log_type”: “DATA_READ” }, { “log_type”: “DATA_WRITE”, “exempted_members”: [ “user:aliya@example.com” ] } ] } ] } For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.
AuditLogConfig
Provides the configuration for logging a type of permissions. Example: { “audit_log_configs”: [ { “log_type”: “DATA_READ”, “exempted_members”: [ “user:jose@example.com” ] }, { “log_type”: “DATA_WRITE” } ] } This enables ‘DATA_READ’ and ‘DATA_WRITE’ logging, while exempting jose@example.com from DATA_READ logging.
AutoAccept
The auto-accept setting for a group controls whether proposed spokes are automatically attached to the hub. If auto-accept is enabled, the spoke immediately is attached to the hub and becomes part of the group. In this case, the new spoke is in the ACTIVE state. If auto-accept is disabled, the spoke goes to the INACTIVE state, and it must be reviewed and accepted by a hub administrator.
AutoCreatedSubnetworkInfo
Information for the automatically created subnetwork and its associated IR.
AutomatedDnsCreationSpec
The specification for automatically creating a DNS record.
Binding
Associates members, or principals, with a role.
CheckConsumerConfigRequest
Request for CheckConsumerConfig.
CheckConsumerConfigResponse
Response for CheckConsumerConfig.
ConsumerPscConfig
Allow the producer to specify which consumers can connect to it.
ConsumerPscConnection
PSC connection details on consumer side.
Destination
The Destination resource. It specifies the IP prefix and the associated autonomous system numbers (ASN) that you want to include in a MulticloudDataTransferConfig resource.
DestinationEndpoint
The metadata for a DestinationEndpoint resource.
DnsAutomationStatus
The status of DNS automation for a PSC connection.
Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }
Expr
Represents a textual expression in the Common Expression Language (CEL) syntax. CEL is a C-like expression language. The syntax and semantics of CEL are documented at https://github.com/google/cel-spec. Example (Comparison): title: “Summary size limit” description: “Determines if a summary is less than 100 chars” expression: “document.summary.size() < 100” Example (Equality): title: “Requestor is owner” description: “Determines if requestor is the document owner” expression: “document.owner == request.auth.claims.email” Example (Logic): title: “Public documents” description: “Determine whether the document should be publicly visible” expression: “document.type != ‘private’ && document.type != ‘internal’” Example (Data Manipulation): title: “Notification string” description: “Create a notification string with a timestamp.” expression: “’New message received at ’ + string(document.create_time)” The exact variables and functions that may be referenced within an expression are determined by the service that evaluates it. See the service documentation for additional information.
Filter
Filter matches L4 traffic.
GoogleLongrunningCancelOperationRequest
The request message for Operations.CancelOperation.
GoogleLongrunningListOperationsResponse
The response message for Operations.ListOperations.
GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
GoogleRpcErrorInfo
Describes the cause of the error with structured details. Example of an error when contacting the “pubsub.googleapis.com” API when it is not enabled: { “reason”: “API_DISABLED” “domain”: “googleapis.com” “metadata”: { “resource”: “projects/123”, “service”: “pubsub.googleapis.com” } } This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: { “reason”: “STOCKOUT” “domain”: “spanner.googleapis.com”, “metadata”: { “availableRegions”: “us-central1,us-east2” } }
GoogleRpcStatus
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide.
Group
A group represents a subset of spokes attached to a hub.
Hub
A Network Connectivity Center hub is a global management resource to which you attach spokes. A single hub can contain spokes from multiple regions. However, if any of a hub’s spokes use the site-to-site data transfer feature, the resources associated with those spokes must all be in the same VPC network. Spokes that do not use site-to-site data transfer can be associated with any VPC network in your project.
HubStatusEntry
A hub status entry represents the status of a set of propagated Private Service Connect connections grouped by certain fields.
InterconnectAttachment
InterconnectAttachment that this route applies to.
InternalRange
The internal range resource for IPAM operations within a VPC network. Used to represent a private address range along with behavioral characteristics of that range (its usage and peering behavior). Networking resources can link to this range if they are created as belonging to it.
LinkedInterconnectAttachments
A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes.
LinkedProducerVpcNetwork
There is no detailed description.
LinkedRouterApplianceInstances
A collection of router appliance instances. If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.
LinkedVpcNetwork
An existing VPC network.
LinkedVpnTunnels
A collection of Cloud VPN tunnel resources. These resources should be redundant HA VPN tunnels that all advertise the same prefixes to Google Cloud. Alternatively, in a passive/active configuration, all tunnels should be capable of advertising the same prefixes.
ListDestinationsResponse
Response message to list Destination resources.
ListGroupsResponse
Response for HubService.ListGroups method.
ListHubSpokesResponse
The response for HubService.ListHubSpokes.
ListHubsResponse
Response for HubService.ListHubs method.
ListInternalRangesResponse
Response for InternalRange.ListInternalRanges
ListLocationsResponse
The response message for Locations.ListLocations.
ListMulticloudDataTransferConfigsResponse
Response message to list MulticloudDataTransferConfig resources.
ListMulticloudDataTransferSupportedServicesResponse
Response message to list the services in your project in regions that are eligible for Data Transfer Essentials configuration.
ListPolicyBasedRoutesResponse
Response for PolicyBasedRoutingService.ListPolicyBasedRoutes method.
ListRegionalEndpointsResponse
Response for ListRegionalEndpoints.
ListRouteTablesResponse
Response for HubService.ListRouteTables method.
ListRoutesResponse
Response for HubService.ListRoutes method.
ListServiceClassesResponse
Response for ListServiceClasses.
ListServiceConnectionMapsResponse
Response for ListServiceConnectionMaps.
ListServiceConnectionPoliciesResponse
Response for ListServiceConnectionPolicies.
ListServiceConnectionTokensResponse
Response for ListServiceConnectionTokens.
ListSpokesResponse
The response for HubService.ListSpokes.
Location
A resource that represents a Google Cloud location.
Migration
Specification for migration with source and target resource names.
MulticloudDataTransferConfig
The MulticloudDataTransferConfig resource. It lists the services that you configure for Data Transfer Essentials billing and metering.
MulticloudDataTransferSupportedService
A service in your project in a region that is eligible for Data Transfer Essentials configuration.
Networkconnectivity
Central instance to access all Networkconnectivity related resource activities
NextHopInterconnectAttachment
A route next hop that leads to an interconnect attachment resource.
NextHopRouterApplianceInstance
A route next hop that leads to a Router appliance instance.
NextHopSpoke
A route next hop that leads to a spoke resource.
NextHopVPNTunnel
A route next hop that leads to a VPN tunnel resource.
NextHopVpcNetwork
There is no detailed description.
Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources. A Policy is a collection of bindings. A binding binds one or more members, or principals, to a single role. Principals can be user accounts, service accounts, Google groups, and domains (such as G Suite). A role is a named list of permissions; each role can be an IAM predefined role or a user-created custom role. For some types of Google Cloud resources, a binding can also specify a condition, which is a logical expression that allows access to a resource only if the expression evaluates to true. A condition can add constraints based on attributes of the request, the resource, or both. To learn which resources support conditions in their IAM policies, see the IAM documentation. JSON example: { "bindings": [ { "role": "roles/resourcemanager.organizationAdmin", "members": [ "user:mike@example.com", "group:admins@example.com", "domain:google.com", "serviceAccount:my-project-id@appspot.gserviceaccount.com" ] }, { "role": "roles/resourcemanager.organizationViewer", "members": [ "user:eve@example.com" ], "condition": { "title": "expirable access", "description": "Does not grant access after Sep 2020", "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')", } } ], "etag": "BwWWja0YfJA=", "version": 3 } YAML example: bindings: - members: - user:mike@example.com - group:admins@example.com - domain:google.com - serviceAccount:my-project-id@appspot.gserviceaccount.com role: roles/resourcemanager.organizationAdmin - members: - user:eve@example.com role: roles/resourcemanager.organizationViewer condition: title: expirable access description: Does not grant access after Sep 2020 expression: request.time < timestamp('2020-10-01T00:00:00.000Z') etag: BwWWja0YfJA= version: 3 For a description of IAM and its features, see the IAM documentation.
PolicyBasedRoute
Policy-based routes route L4 network traffic based on not just destination IP address, but also source IP address, protocol, and more. If a policy-based route conflicts with other types of routes, the policy-based route always takes precedence.
ProducerPscConfig
The PSC configurations on producer side.
ProjectLocationCheckConsumerConfigCall
CheckConsumerConfig validates the consumer network and project for potential PSC connection creation. This method performs several checks, including: - Validating the existence and permissions of the service class. - Ensuring the consumer network exists and is accessible. - Verifying XPN relationships if applicable. - Checking for compatible IP versions between the consumer network and the requested version. This method performs a dynamic IAM check for the networkconnectivity.serviceClasses.use permission on the service class resource in the Prepare phase.
ProjectLocationGetCall
Gets information about a location.
ProjectLocationGlobalHubAcceptSpokeCall
Accepts a proposal to attach a Network Connectivity Center spoke to a hub.
ProjectLocationGlobalHubAcceptSpokeUpdateCall
Accepts a proposal to update a Network Connectivity Center spoke in a hub.
ProjectLocationGlobalHubCreateCall
Creates a new Network Connectivity Center hub in the specified project.
ProjectLocationGlobalHubDeleteCall
Deletes a Network Connectivity Center hub.
ProjectLocationGlobalHubGetCall
Gets details about a Network Connectivity Center hub.
ProjectLocationGlobalHubGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationGlobalHubGroupGetCall
Gets details about a Network Connectivity Center group.
ProjectLocationGlobalHubGroupGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationGlobalHubGroupListCall
Lists groups in a given hub.
ProjectLocationGlobalHubGroupPatchCall
Updates the parameters of a Network Connectivity Center group.
ProjectLocationGlobalHubGroupSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationGlobalHubGroupTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationGlobalHubListCall
Lists the Network Connectivity Center hubs associated with a given project.
ProjectLocationGlobalHubListSpokeCall
Lists the Network Connectivity Center spokes associated with a specified hub and location. The list includes both spokes that are attached to the hub and spokes that have been proposed but not yet accepted.
ProjectLocationGlobalHubPatchCall
Updates the description and/or labels of a Network Connectivity Center hub.
ProjectLocationGlobalHubQueryStatuCall
Query the Private Service Connect propagation status of a Network Connectivity Center hub.
ProjectLocationGlobalHubRejectSpokeCall
Rejects a Network Connectivity Center spoke from being attached to a hub. If the spoke was previously in the ACTIVE state, it transitions to the INACTIVE state and is no longer able to connect to other spokes that are attached to the hub.
ProjectLocationGlobalHubRejectSpokeUpdateCall
Rejects a proposal to update a Network Connectivity Center spoke in a hub.
ProjectLocationGlobalHubRouteTableGetCall
Gets details about a Network Connectivity Center route table.
ProjectLocationGlobalHubRouteTableListCall
Lists route tables in a given hub.
ProjectLocationGlobalHubRouteTableRouteGetCall
Gets details about the specified route.
ProjectLocationGlobalHubRouteTableRouteListCall
Lists routes in a given route table.
ProjectLocationGlobalHubSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationGlobalHubTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationGlobalPolicyBasedRouteCreateCall
Creates a new policy-based route in a given project and location.
ProjectLocationGlobalPolicyBasedRouteDeleteCall
Deletes a single policy-based route.
ProjectLocationGlobalPolicyBasedRouteGetCall
Gets details of a single policy-based route.
ProjectLocationGlobalPolicyBasedRouteGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationGlobalPolicyBasedRouteListCall
Lists policy-based routes in a given project and location.
ProjectLocationGlobalPolicyBasedRouteSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationGlobalPolicyBasedRouteTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationInternalRangeCreateCall
Creates a new internal range in a given project and location.
ProjectLocationInternalRangeDeleteCall
Deletes a single internal range.
ProjectLocationInternalRangeGetCall
Gets details of a single internal range.
ProjectLocationInternalRangeGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationInternalRangeListCall
Lists internal ranges in a given project and location.
ProjectLocationInternalRangePatchCall
Updates the parameters of a single internal range.
ProjectLocationInternalRangeSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationInternalRangeTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationListCall
Lists information about the supported locations for this service.
ProjectLocationMulticloudDataTransferConfigCreateCall
Creates a MulticloudDataTransferConfig resource in a specified project and location.
ProjectLocationMulticloudDataTransferConfigDeleteCall
Deletes a MulticloudDataTransferConfig resource.
ProjectLocationMulticloudDataTransferConfigDestinationCreateCall
Creates a Destination resource in a specified project and location.
ProjectLocationMulticloudDataTransferConfigDestinationDeleteCall
Deletes a Destination resource.
ProjectLocationMulticloudDataTransferConfigDestinationGetCall
Gets the details of a Destination resource.
ProjectLocationMulticloudDataTransferConfigDestinationListCall
Lists the Destination resources in a specified project and location.
ProjectLocationMulticloudDataTransferConfigDestinationPatchCall
Updates a Destination resource in a specified project and location.
ProjectLocationMulticloudDataTransferConfigGetCall
Gets the details of a MulticloudDataTransferConfig resource.
ProjectLocationMulticloudDataTransferConfigListCall
Lists the MulticloudDataTransferConfig resources in a specified project and location.
ProjectLocationMulticloudDataTransferConfigPatchCall
Updates a MulticloudDataTransferConfig resource in a specified project and location.
ProjectLocationMulticloudDataTransferSupportedServiceGetCall
Gets the details of a service that is supported for Data Transfer Essentials.
ProjectLocationMulticloudDataTransferSupportedServiceListCall
Lists the services in the project for a region that are supported for Data Transfer Essentials.
ProjectLocationOperationCancelCall
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
ProjectLocationOperationDeleteCall
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn’t support this method, it returns google.rpc.Code.UNIMPLEMENTED.
ProjectLocationOperationGetCall
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
ProjectLocationOperationListCall
Lists operations that match the specified filter in the request. If the server doesn’t support this method, it returns UNIMPLEMENTED.
ProjectLocationRegionalEndpointCreateCall
Creates a new RegionalEndpoint in a given project and location.
ProjectLocationRegionalEndpointDeleteCall
Deletes a single RegionalEndpoint.
ProjectLocationRegionalEndpointGetCall
Gets details of a single RegionalEndpoint.
ProjectLocationRegionalEndpointListCall
Lists RegionalEndpoints in a given project and location.
ProjectLocationServiceClassDeleteCall
Deletes a single ServiceClass.
ProjectLocationServiceClassGetCall
Gets details of a single ServiceClass.
ProjectLocationServiceClassGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationServiceClassListCall
Lists ServiceClasses in a given project and location.
ProjectLocationServiceClassPatchCall
Updates the parameters of a single ServiceClass.
ProjectLocationServiceClassSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationServiceClassTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationServiceConnectionMapCreateCall
Creates a new ServiceConnectionMap in a given project and location.
ProjectLocationServiceConnectionMapDeleteCall
Deletes a single ServiceConnectionMap.
ProjectLocationServiceConnectionMapGetCall
Gets details of a single ServiceConnectionMap.
ProjectLocationServiceConnectionMapGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationServiceConnectionMapListCall
Lists ServiceConnectionMaps in a given project and location.
ProjectLocationServiceConnectionMapPatchCall
Updates the parameters of a single ServiceConnectionMap.
ProjectLocationServiceConnectionMapSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationServiceConnectionMapTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationServiceConnectionPolicyCreateCall
Creates a new ServiceConnectionPolicy in a given project and location.
ProjectLocationServiceConnectionPolicyDeleteCall
Deletes a single ServiceConnectionPolicy.
ProjectLocationServiceConnectionPolicyGetCall
Gets details of a single ServiceConnectionPolicy.
ProjectLocationServiceConnectionPolicyGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationServiceConnectionPolicyListCall
Lists ServiceConnectionPolicies in a given project and location.
ProjectLocationServiceConnectionPolicyPatchCall
Updates the parameters of a single ServiceConnectionPolicy.
ProjectLocationServiceConnectionPolicySetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationServiceConnectionPolicyTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectLocationServiceConnectionTokenCreateCall
Creates a new ServiceConnectionToken in a given project and location.
ProjectLocationServiceConnectionTokenDeleteCall
Deletes a single ServiceConnectionToken.
ProjectLocationServiceConnectionTokenGetCall
Gets details of a single ServiceConnectionToken.
ProjectLocationServiceConnectionTokenListCall
Lists ServiceConnectionTokens in a given project and location.
ProjectLocationSpokeCreateCall
Creates a Network Connectivity Center spoke.
ProjectLocationSpokeDeleteCall
Deletes a Network Connectivity Center spoke.
ProjectLocationSpokeGetCall
Gets details about a Network Connectivity Center spoke.
ProjectLocationSpokeGetIamPolicyCall
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
ProjectLocationSpokeListCall
Lists the Network Connectivity Center spokes in a specified project and location.
ProjectLocationSpokePatchCall
Updates the parameters of a Network Connectivity Center spoke.
ProjectLocationSpokeSetIamPolicyCall
Sets the access control policy on the specified resource. Replaces any existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and PERMISSION_DENIED errors.
ProjectLocationSpokeTestIamPermissionCall
Returns permissions that a caller has on the specified resource. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error. Note: This operation is designed to be used for building permission-aware UIs and command-line tools, not for authorization checking. This operation may “fail open” without warning.
ProjectMethods
A builder providing access to all methods supported on project resources. It is not used directly, but through the Networkconnectivity hub.
PscConfig
Configuration used for Private Service Connect connections. Used when Infrastructure is PSC.
PscConnection
Information about a specific Private Service Connect connection.
PscPropagationStatus
The status of one or more propagated Private Service Connect connections in a hub.
QueryHubStatusResponse
The response for HubService.QueryHubStatus.
RegionalEndpoint
The RegionalEndpoint resource.
RejectHubSpokeRequest
The request for HubService.RejectHubSpoke.
RejectSpokeUpdateRequest
The request for HubService.RejectSpokeUpdate.
Route
A route defines a path from VM instances within a spoke to a specific destination resource. Only VPC spokes have routes.
RouteTable
There is no detailed description.
RouterApplianceInstance
A router appliance instance is a Compute Engine virtual machine (VM) instance that acts as a BGP speaker. A router appliance instance is specified by the URI of the VM and the internal IP address of one of the VM’s network interfaces.
RoutingVPC
RoutingVPC contains information about the VPC networks associated with the spokes of a Network Connectivity Center hub.
ServiceClass
The ServiceClass resource.
ServiceConfig
Specifies eligibility information for the service.
ServiceConnectionMap
The ServiceConnectionMap resource.
ServiceConnectionPolicy
The ServiceConnectionPolicy resource.
ServiceConnectionToken
The ServiceConnectionToken resource.
SetIamPolicyRequest
Request message for SetIamPolicy method.
Spoke
A Network Connectivity Center spoke represents one or more network connectivity resources. When you create a spoke, you associate it with a hub. You must also identify a value for exactly one of the following fields: * linked_vpn_tunnels * linked_interconnect_attachments * linked_router_appliance_instances * linked_vpc_network
SpokeStateCount
The number of spokes that are in a particular state and associated with a given hub.
SpokeStateReasonCount
The number of spokes in the hub that are inactive for this reason.
SpokeSummary
Summarizes information about the spokes associated with a hub. The summary includes a count of spokes according to type and according to state. If any spokes are inactive, the summary also lists the reasons they are inactive, including a count for each reason.
SpokeTypeCount
The number of spokes of a given type that are associated with a specific hub. The type indicates what kind of resource is associated with the spoke.
StateMetadata
The state and activation time details of the resource state.
StateReason
The reason a spoke is inactive.
StateTimeline
The timeline of the pending states for a resource.
TestIamPermissionsRequest
Request message for TestIamPermissions method.
TestIamPermissionsResponse
Response message for TestIamPermissions method.
VirtualMachine
VM instances that this policy-based route applies to.
Warnings
Informational warning message.

Enums

Scope
Identifies the an OAuth2 authorization scope. A scope is needed when requesting an authorization token.