pub struct ConsumerPscConfig {
pub consumer_instance_project: Option<String>,
pub disable_global_access: Option<bool>,
pub ip_version: Option<String>,
pub network: Option<String>,
pub producer_instance_id: Option<String>,
pub producer_instance_metadata: Option<HashMap<String, String>>,
pub project: Option<String>,
pub service_attachment_ip_address_map: Option<HashMap<String, String>>,
pub state: Option<String>,
}Expand description
Allow the producer to specify which consumers can connect to it.
This type is not used in any activity, and only used as part of another schema.
Fields
consumer_instance_project: Option<String>Required. The project ID or project number of the consumer project. This project is the one that the consumer uses to interact with the producer instance. From the perspective of a consumer who’s created a producer instance, this is the project of the producer instance. Format: ‘projects/’ Eg. ‘projects/consumer-project’ or ‘projects/1234’
disable_global_access: Option<bool>This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region.
ip_version: Option<String>The requested IP version for the PSC connection.
network: Option<String>The resource path of the consumer network where PSC connections are allowed to be created in. Note, this network does not need be in the ConsumerPscConfig.project in the case of SharedVPC. Example: projects/{projectNumOrId}/global/networks/{networkId}.
producer_instance_id: Option<String>Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance.
producer_instance_metadata: Option<HashMap<String, String>>Immutable. An immutable map for the producer instance metadata.
project: Option<String>The consumer project where PSC connections are allowed to be created in.
service_attachment_ip_address_map: Option<HashMap<String, String>>Optional. A map to store mapping between customer vip and target service attachment. This field can be used to specify a static IP address for a PSC connection.
state: Option<String>Output only. Overall state of PSC Connections management for this consumer psc config.