pub struct ConsumerPscConnection {Show 16 fields
pub dns_automation_status: Option<DnsAutomationStatus>,
pub error: Option<GoogleRpcStatus>,
pub error_info: Option<GoogleRpcErrorInfo>,
pub error_type: Option<String>,
pub forwarding_rule: Option<String>,
pub gce_operation: Option<String>,
pub ip: Option<String>,
pub ip_version: Option<String>,
pub network: Option<String>,
pub producer_instance_id: Option<String>,
pub producer_instance_metadata: Option<HashMap<String, String>>,
pub project: Option<String>,
pub psc_connection_id: Option<String>,
pub selected_subnetwork: Option<String>,
pub service_attachment_uri: Option<String>,
pub state: Option<String>,
}Expand description
PSC connection details on consumer side.
This type is not used in any activity, and only used as part of another schema.
Fields
dns_automation_status: Option<DnsAutomationStatus>Output only. The status of DNS automation for this PSC connection.
error: Option<GoogleRpcStatus>The most recent error during operating this connection.
error_info: Option<GoogleRpcErrorInfo>Output only. The error info for the latest error during operating this connection.
error_type: Option<String>The error type indicates whether the error is consumer facing, producer facing or system internal.
forwarding_rule: Option<String>The URI of the consumer forwarding rule created. Example: projects/{projectNumOrId}/regions/us-east1/networks/{resourceId}.
gce_operation: Option<String>The last Compute Engine operation to setup PSC connection.
ip: Option<String>The IP literal allocated on the consumer network for the PSC forwarding rule that is created to connect to the producer service attachment in this service connection map.
ip_version: Option<String>The requested IP version for the PSC connection.
network: Option<String>The consumer network whose PSC forwarding rule is connected to the service attachments in this service connection map. Note that the network could be on a different project (shared VPC).
producer_instance_id: Option<String>Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance.
producer_instance_metadata: Option<HashMap<String, String>>Immutable. An immutable map for the producer instance metadata.
project: Option<String>The consumer project whose PSC forwarding rule is connected to the service attachments in this service connection map.
psc_connection_id: Option<String>The PSC connection id of the PSC forwarding rule connected to the service attachments in this service connection map.
selected_subnetwork: Option<String>Output only. The URI of the selected subnetwork selected to allocate IP address for this connection.
service_attachment_uri: Option<String>The URI of a service attachment which is the target of the PSC connection.
state: Option<String>The state of the PSC connection.