pub struct Group {
pub auto_accept: Option<AutoAccept>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub route_table: Option<String>,
pub state: Option<String>,
pub uid: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A group represents a subset of spokes attached to a hub.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations global hubs groups get projects (response)
- locations global hubs groups patch projects (request)
Fields
auto_accept: Option<AutoAccept>Optional. The auto-accept setting for this group.
create_time: Option<DateTime<Utc>>Output only. The time the group was created.
description: Option<String>Optional. The description of the group.
labels: Option<HashMap<String, String>>Optional. Labels in key-value pair format. For more information about labels, see Requirements for labels.
name: Option<String>Immutable. The name of the group. Group names must be unique. They use the following form: projects/{project_number}/locations/global/hubs/{hub}/groups/{group_id}
route_table: Option<String>Output only. The name of the route table that corresponds to this group. They use the following form: projects/{project_number}/locations/global/hubs/{hub_id}/routeTables/{route_table_id}
state: Option<String>Output only. The current lifecycle state of this group.
uid: Option<String>Output only. The Google-generated UUID for the group. This value is unique across all group resources. If a group is deleted and another with the same name is created, the new route table is assigned a different unique_id.
update_time: Option<DateTime<Utc>>Output only. The time the group was last updated.