pub struct InterconnectAttachment {
pub region: Option<String>,
}Expand description
InterconnectAttachment that this route applies to.
This type is not used in any activity, and only used as part of another schema.
Fields
region: Option<String>Optional. Cloud region to install this policy-based route on interconnect attachment. Use all to install it on all interconnect attachments.