pub struct LinkedInterconnectAttachments {
pub include_import_ranges: Option<Vec<String>>,
pub site_to_site_data_transfer: Option<bool>,
pub uris: Option<Vec<String>>,
pub vpc_network: Option<String>,
}Expand description
A collection of VLAN attachment resources. These resources should be redundant attachments that all advertise the same prefixes to Google Cloud. Alternatively, in active/passive configurations, all attachments should be capable of advertising the same prefixes.
This type is not used in any activity, and only used as part of another schema.
Fields
include_import_ranges: Option<Vec<String>>Optional. Hub routes fully encompassed by include import ranges are included during import from hub.
site_to_site_data_transfer: Option<bool>A value that controls whether site-to-site data transfer is enabled for these resources. Data transfer is available only in supported locations.
uris: Option<Vec<String>>The URIs of linked interconnect attachment resources
vpc_network: Option<String>Output only. The VPC network where these VLAN attachments are located.