LinkedProducerVpcNetwork

Struct LinkedProducerVpcNetwork 

pub struct LinkedProducerVpcNetwork {
    pub exclude_export_ranges: Option<Vec<String>>,
    pub include_export_ranges: Option<Vec<String>>,
    pub network: Option<String>,
    pub peering: Option<String>,
    pub producer_network: Option<String>,
    pub proposed_exclude_export_ranges: Option<Vec<String>>,
    pub proposed_include_export_ranges: Option<Vec<String>>,
    pub service_consumer_vpc_spoke: Option<String>,
}
There is no detailed description.

This type is not used in any activity, and only used as part of another schema.

Fields

exclude_export_ranges: Option<Vec<String>>

Optional. IP ranges encompassing the subnets to be excluded from peering.

include_export_ranges: Option<Vec<String>>

Optional. IP ranges allowed to be included from peering.

network: Option<String>

Immutable. The URI of the Service Consumer VPC that the Producer VPC is peered with.

peering: Option<String>

Immutable. The name of the VPC peering between the Service Consumer VPC and the Producer VPC (defined in the Tenant project) which is added to the NCC hub. This peering must be in ACTIVE state.

producer_network: Option<String>

Output only. The URI of the Producer VPC.

proposed_exclude_export_ranges: Option<Vec<String>>

Output only. The proposed exclude export IP ranges waiting for hub administration’s approval.

proposed_include_export_ranges: Option<Vec<String>>

Output only. The proposed include export IP ranges waiting for hub administration’s approval.

service_consumer_vpc_spoke: Option<String>

Output only. The Service Consumer Network spoke.