pub struct ListPolicyBasedRoutesResponse {
pub next_page_token: Option<String>,
pub policy_based_routes: Option<Vec<PolicyBasedRoute>>,
pub unreachable: Option<Vec<String>>,
}Expand description
Response for PolicyBasedRoutingService.ListPolicyBasedRoutes method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
next_page_token: Option<String>The next pagination token in the List response. It should be used as page_token for the following request. An empty value means no more result.
policy_based_routes: Option<Vec<PolicyBasedRoute>>Policy-based routes to be returned.
unreachable: Option<Vec<String>>Locations that could not be reached.