pub struct NextHopInterconnectAttachment {
pub site_to_site_data_transfer: Option<bool>,
pub uri: Option<String>,
pub vpc_network: Option<String>,
}Expand description
A route next hop that leads to an interconnect attachment resource.
This type is not used in any activity, and only used as part of another schema.
Fields
site_to_site_data_transfer: Option<bool>Indicates whether site-to-site data transfer is allowed for this interconnect attachment resource. Data transfer is available only in supported locations.
uri: Option<String>The URI of the interconnect attachment resource.
vpc_network: Option<String>The VPC network where this interconnect attachment is located.