pub struct PscConnection {Show 14 fields
pub consumer_address: Option<String>,
pub consumer_forwarding_rule: Option<String>,
pub consumer_target_project: Option<String>,
pub error: Option<GoogleRpcStatus>,
pub error_info: Option<GoogleRpcErrorInfo>,
pub error_type: Option<String>,
pub gce_operation: Option<String>,
pub ip_version: Option<String>,
pub producer_instance_id: Option<String>,
pub producer_instance_metadata: Option<HashMap<String, String>>,
pub psc_connection_id: Option<String>,
pub selected_subnetwork: Option<String>,
pub service_class: Option<String>,
pub state: Option<String>,
}Expand description
Information about a specific Private Service Connect connection.
This type is not used in any activity, and only used as part of another schema.
Fields
consumer_address: Option<String>The resource reference of the consumer address.
consumer_forwarding_rule: Option<String>The resource reference of the PSC Forwarding Rule within the consumer VPC.
consumer_target_project: Option<String>The project where the PSC connection is created.
error: Option<GoogleRpcStatus>The most recent error during operating this connection. Deprecated, please use error_info instead.
error_info: Option<GoogleRpcErrorInfo>Output only. The error info for the latest error during operating this connection.
error_type: Option<String>The error type indicates whether the error is consumer facing, producer facing or system internal.
gce_operation: Option<String>The last Compute Engine operation to setup PSC connection.
ip_version: Option<String>The requested IP version for the PSC connection.
producer_instance_id: Option<String>Immutable. Deprecated. Use producer_instance_metadata instead. An immutable identifier for the producer instance.
producer_instance_metadata: Option<HashMap<String, String>>Immutable. An immutable map for the producer instance metadata.
psc_connection_id: Option<String>The PSC connection id of the PSC forwarding rule.
selected_subnetwork: Option<String>Output only. The URI of the subnetwork selected to allocate IP address for this connection.
service_class: Option<String>Output only. [Output only] The service class associated with this PSC Connection. The value is derived from the SCPolicy and matches the service class name provided by the customer.
state: Option<String>State of the PSC Connection