pub struct RegionalEndpoint {
pub access_type: Option<String>,
pub address: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub ip_address: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub name: Option<String>,
pub network: Option<String>,
pub psc_forwarding_rule: Option<String>,
pub subnetwork: Option<String>,
pub target_google_api: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
The RegionalEndpoint resource.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations regional endpoints create projects (request)
- locations regional endpoints get projects (response)
Fields
access_type: Option<String>Required. The access type of this regional endpoint. This field is reflected in the PSC Forwarding Rule configuration to enable global access.
address: Option<String>Optional. The IP Address of the Regional Endpoint. When no address is provided, an IP from the subnetwork is allocated. Use one of the following formats: * IPv4 address as in 10.0.0.1 * Address resource URI as in projects/{project}/regions/{region}/addresses/{address_name} for an IPv4 or IPv6 address.
create_time: Option<DateTime<Utc>>Output only. Time when the RegionalEndpoint was created.
description: Option<String>Optional. A description of this resource.
ip_address: Option<String>Output only. The literal IP address of the PSC Forwarding Rule created on behalf of the customer. This field is deprecated. Use address instead.
labels: Option<HashMap<String, String>>User-defined labels.
name: Option<String>Output only. The name of a RegionalEndpoint. Pattern: projects/{project}/locations/{location}/regionalEndpoints/^[-a-z0-9](?:[-a-z0-9]{0,44})[a-z0-9]$.
network: Option<String>Optional. The name of the VPC network for this private regional endpoint. Format: projects/{project}/global/networks/{network}
psc_forwarding_rule: Option<String>Output only. The resource reference of the PSC Forwarding Rule created on behalf of the customer. Format: //compute.googleapis.com/projects/{project}/regions/{region}/forwardingRules/{forwarding_rule_name}
subnetwork: Option<String>Optional. The name of the subnetwork from which the IP address will be allocated. Format: projects/{project}/regions/{region}/subnetworks/{subnetwork}
target_google_api: Option<String>Required. The service endpoint this private regional endpoint connects to. Format: {apiname}.{region}.p.rep.googleapis.com Example: “cloudkms.us-central1.p.rep.googleapis.com”.
update_time: Option<DateTime<Utc>>Output only. Time when the RegionalEndpoint was updated.