RouteTable

Struct RouteTable 

pub struct RouteTable {
    pub create_time: Option<DateTime<Utc>>,
    pub description: Option<String>,
    pub labels: Option<HashMap<String, String>>,
    pub name: Option<String>,
    pub state: Option<String>,
    pub uid: Option<String>,
    pub update_time: Option<DateTime<Utc>>,
}
There is no detailed description.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

create_time: Option<DateTime<Utc>>

Output only. The time the route table was created.

description: Option<String>

An optional description of the route table.

labels: Option<HashMap<String, String>>

Optional labels in key-value pair format. For more information about labels, see Requirements for labels.

name: Option<String>

Immutable. The name of the route table. Route table names must be unique. They use the following form: projects/{project_number}/locations/global/hubs/{hub}/routeTables/{route_table_id}

state: Option<String>

Output only. The current lifecycle state of this route table.

uid: Option<String>

Output only. The Google-generated UUID for the route table. This value is unique across all route table resources. If a route table is deleted and another with the same name is created, the new route table is assigned a different uid.

update_time: Option<DateTime<Utc>>

Output only. The time the route table was last updated.