pub struct Spoke {Show 18 fields
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub etag: Option<String>,
pub field_paths_pending_update: Option<Vec<String>>,
pub group: Option<String>,
pub hub: Option<String>,
pub labels: Option<HashMap<String, String>>,
pub linked_interconnect_attachments: Option<LinkedInterconnectAttachments>,
pub linked_producer_vpc_network: Option<LinkedProducerVpcNetwork>,
pub linked_router_appliance_instances: Option<LinkedRouterApplianceInstances>,
pub linked_vpc_network: Option<LinkedVpcNetwork>,
pub linked_vpn_tunnels: Option<LinkedVpnTunnels>,
pub name: Option<String>,
pub reasons: Option<Vec<StateReason>>,
pub spoke_type: Option<String>,
pub state: Option<String>,
pub unique_id: Option<String>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
A Network Connectivity Center spoke represents one or more network connectivity resources. When you create a spoke, you associate it with a hub. You must also identify a value for exactly one of the following fields: * linked_vpn_tunnels * linked_interconnect_attachments * linked_router_appliance_instances * linked_vpc_network
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations spokes create projects (request)
- locations spokes get projects (response)
- locations spokes patch projects (request)
Fields
create_time: Option<DateTime<Utc>>Output only. The time the spoke was created.
description: Option<String>Optional. An optional description of the spoke.
etag: Option<String>Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
field_paths_pending_update: Option<Vec<String>>Optional. The list of fields waiting for hub administration’s approval.
group: Option<String>Optional. The name of the group that this spoke is associated with.
hub: Option<String>Immutable. The name of the hub that this spoke is attached to.
labels: Option<HashMap<String, String>>Optional labels in key-value pair format. For more information about labels, see Requirements for labels.
linked_interconnect_attachments: Option<LinkedInterconnectAttachments>Optional. VLAN attachments that are associated with the spoke.
linked_producer_vpc_network: Option<LinkedProducerVpcNetwork>Optional. The linked producer VPC that is associated with the spoke.
linked_router_appliance_instances: Option<LinkedRouterApplianceInstances>Optional. Router appliance instances that are associated with the spoke.
linked_vpc_network: Option<LinkedVpcNetwork>Optional. VPC network that is associated with the spoke.
linked_vpn_tunnels: Option<LinkedVpnTunnels>Optional. VPN tunnels that are associated with the spoke.
name: Option<String>Immutable. The name of the spoke. Spoke names must be unique. They use the following form: projects/{project_number}/locations/{region}/spokes/{spoke_id}
reasons: Option<Vec<StateReason>>Output only. The reasons for current state of the spoke.
spoke_type: Option<String>Output only. The type of resource associated with the spoke.
state: Option<String>Output only. The current lifecycle state of this spoke.
unique_id: Option<String>Output only. The Google-generated UUID for the spoke. This value is unique across all spoke resources. If a spoke is deleted and another with the same name is created, the new spoke is assigned a different unique_id.
update_time: Option<DateTime<Utc>>Output only. The time the spoke was last updated.