pub struct LinkedVpcNetwork {
pub exclude_export_ranges: Option<Vec<String>>,
pub include_export_ranges: Option<Vec<String>>,
pub producer_vpc_spokes: Option<Vec<String>>,
pub proposed_exclude_export_ranges: Option<Vec<String>>,
pub proposed_include_export_ranges: Option<Vec<String>>,
pub uri: Option<String>,
}Expand description
An existing VPC network.
This type is not used in any activity, and only used as part of another schema.
Fields
exclude_export_ranges: Option<Vec<String>>Optional. IP ranges encompassing the subnets to be excluded from peering.
include_export_ranges: Option<Vec<String>>Optional. IP ranges allowed to be included from peering.
producer_vpc_spokes: Option<Vec<String>>Output only. The list of Producer VPC spokes that this VPC spoke is a service consumer VPC spoke for. These producer VPCs are connected through VPC peering to this spoke’s backing VPC network. Because they are directly connected through VPC peering, NCC export filters do not apply between the service consumer VPC spoke and any of its producer VPC spokes. This VPC spoke cannot be deleted as long as any of these producer VPC spokes are connected to the NCC Hub.
proposed_exclude_export_ranges: Option<Vec<String>>Output only. The proposed exclude export IP ranges waiting for hub administration’s approval.
proposed_include_export_ranges: Option<Vec<String>>Output only. The proposed include export IP ranges waiting for hub administration’s approval.
uri: Option<String>Required. The URI of the VPC network resource.